""" Copyright (c) 2003-2008 LOGILAB S.A. (Paris, FRANCE).
http://www.logilab.fr/ -- mailto:contact@logilab.fr

Logilab's developpment tools
"""

from os.path import join, dirname
TEMPLATE_DIR = join(dirname(__file__), 'templates')
del join
